{%
include-markdown "../README.md"
start="<!--haliax-intro-start-->"
end="<!--haliax-intro-end-->"
%}


The code is released on GitHub: [Haliax Repository](https://github.com/stanford-crfm/haliax/).


To contribute, please refer to the [Contributing Guide](https://github.com/stanford-crfm/haliax/blob/main/CONTRIBUTING.md).
